rytm_rs::object::kit

Struct Kit

pub struct Kit { /* private fields */ }
Represents a kit in the analog rytm.

It does not map identically to the structure in the firmware.

Implementations

Source

impl Kit

pub fn try_default(kit_index: usize) -> Result<Self, RytmError>

Makes a new kit with the given index complying to project defaults.

Range: 0..=127

pub fn work_buffer_default() -> Self

Makes a new kit in the work buffer complying to project defaults as if it comes from the work buffer.

pub fn set_name(&mut self, name: &str) -> Result<(), RytmError>

Sets the name of the kit.

Errors

The name must be ASCII and have a length of 15 characters or less. Other cases will result in an error.

pub fn name(&self) -> &str

Returns the name of the kit.

pub const fn sounds(&self) -> &[Sound; 12]

Returns the sounds assigned to the kit in the order of the tracks.

pub fn sounds_mut(&mut self) -> &mut [Sound; 12]

Returns the sounds assigned to the kit in the order of the tracks mutably.

pub fn set_track_level( &mut self, track_index: usize, level: usize, ) -> Result<(), RytmError>

Sets the level of a track.

Range 0..=12

12th track is the fx track.

pub fn set_all_track_levels(&mut self, level: usize) -> Result<(), RytmError>

Sets the level of all tracks including the Fx track.

Range 0..=127

pub fn set_a_range_of_track_levels( &mut self, range: Range<usize>, level: usize, ) -> Result<(), RytmError>

Sets the level of a range of tracks.

12th track is the fx track.

Maximum range 0..=12

Level range 0..=127

pub fn track_level(&self, track_index: usize) -> Result<usize, RytmError>

Gets the level of a track.

Range 0..=12

pub fn track_levels(&self) -> Vec<usize>

Gets the level of all tracks including the Fx track.

Range 0..=127

pub fn range_of_track_levels( &self, range: Range<usize>, ) -> Result<Vec<usize>, RytmError>

Gets the level of a range of tracks.

12th track is the fx track.

Maximum range 0..=12

Level range 0..=127

Errors

Returns an error if the range is out of bounds.

pub const fn structure_version(&self) -> u32

Returns the version of the kit structure.

pub fn track_retrig_settings( &self, track_index: usize, ) -> Result<&TrackRetrigMenu, RytmError>

Gets the retrig menu of a track

12th track is the fx track.

Range 0..=12

pub fn track_retrig_settings_mut( &mut self, track_index: usize, ) -> Result<&mut TrackRetrigMenu, RytmError>

Gets the retrig menu of a track mutably

12th track is the fx track.

Range 0..=12

pub const fn fx_delay(&self) -> &FxDelay

Gets the fx delay parameters.

pub fn fx_delay_mut(&mut self) -> &mut FxDelay

Gets the fx delay parameters mutably.

pub const fn fx_distortion(&self) -> &FxDistortion

Gets the fx distortion parameters.

pub fn fx_distortion_mut(&mut self) -> &mut FxDistortion

Gets the fx distortion parameters mutably.

pub const fn fx_reverb(&self) -> &FxReverb

Gets the fx reverb parameters.

pub fn fx_reverb_mut(&mut self) -> &mut FxReverb

Gets the fx reverb parameters mutably.

pub const fn fx_compressor(&self) -> &FxCompressor

Gets the fx compressor parameters.

pub fn fx_compressor_mut(&mut self) -> &mut FxCompressor

Gets the fx compressor parameters mutably.

pub const fn fx_lfo(&self) -> &FxLfo

Gets the fx lfo parameters.

pub fn fx_lfo_mut(&mut self) -> &mut FxLfo

Gets the fx lfo parameters mutably.

pub const fn index(&self) -> usize

Returns the index of the kit.

pub fn set_control_in_1_mod_target_1( &mut self, control_in_1_mod_target_1: ControlInModTarget, )

Sets the control in 1 mod target 1

pub fn set_control_in_1_mod_target_2( &mut self, control_in_1_mod_target_2: ControlInModTarget, )

Sets the control in 1 mod target 2

pub fn set_control_in_1_mod_target_3( &mut self, control_in_1_mod_target_3: ControlInModTarget, )

Sets the control in 1 mod target 3

pub fn set_control_in_1_mod_target_4( &mut self, control_in_1_mod_target_4: ControlInModTarget, )

Sets the control in 1 mod target 4

pub fn set_control_in_2_mod_target_1( &mut self, control_in_2_mod_target_1: ControlInModTarget, )

Sets the control in 2 mod target 1

pub fn set_control_in_2_mod_target_2( &mut self, control_in_2_mod_target_2: ControlInModTarget, )

Sets the control in 2 mod target 2

pub fn set_control_in_2_mod_target_3( &mut self, control_in_2_mod_target_3: ControlInModTarget, )

Sets the control in 2 mod target 3

pub fn set_control_in_2_mod_target_4( &mut self, control_in_2_mod_target_4: ControlInModTarget, )

Sets the control in 2 mod target 4

pub fn set_control_in_1_mod_amt_1( &mut self, control_in_1_mod_amt_1: isize, ) -> Result<(), RytmError>

Sets the control in 1 mod amt 1

Range: -128..=127

pub fn set_control_in_1_mod_amt_2( &mut self, control_in_1_mod_amt_2: isize, ) -> Result<(), RytmError>

Sets the control in 1 mod amt 2

Range: -128..=127

pub fn set_control_in_1_mod_amt_3( &mut self, control_in_1_mod_amt_3: isize, ) -> Result<(), RytmError>

Sets the control in 1 mod amt 3

Range: -128..=127

pub fn set_control_in_1_mod_amt_4( &mut self, control_in_1_mod_amt_4: isize, ) -> Result<(), RytmError>

Sets the control in 1 mod amt 4

Range: -128..=127

pub fn set_control_in_2_mod_amt_1( &mut self, control_in_2_mod_amt_1: isize, ) -> Result<(), RytmError>

Sets the control in 2 mod amt 1

Range: -128..=127

pub fn set_control_in_2_mod_amt_2( &mut self, control_in_2_mod_amt_2: isize, ) -> Result<(), RytmError>

Sets the control in 2 mod amt 2

Range: -128..=127

pub fn set_control_in_2_mod_amt_3( &mut self, control_in_2_mod_amt_3: isize, ) -> Result<(), RytmError>

Sets the control in 2 mod amt 3

Range: -128..=127

pub fn set_control_in_2_mod_amt_4( &mut self, control_in_2_mod_amt_4: isize, ) -> Result<(), RytmError>

Sets the control in 2 mod amt 4

Range: -128..=127

pub const fn control_in_1_mod_target_1(&self) -> ControlInModTarget

Gets the control in 1 mod target 1

pub const fn control_in_1_mod_target_2(&self) -> ControlInModTarget

Gets the control in 1 mod target 2

pub const fn control_in_1_mod_target_3(&self) -> ControlInModTarget

Gets the control in 1 mod target 3

pub const fn control_in_1_mod_target_4(&self) -> ControlInModTarget

Gets the control in 1 mod target 4

pub const fn control_in_2_mod_target_1(&self) -> ControlInModTarget

Gets the control in 2 mod target 1

pub const fn control_in_2_mod_target_2(&self) -> ControlInModTarget

Gets the control in 2 mod target 2

pub const fn control_in_2_mod_target_3(&self) -> ControlInModTarget

Gets the control in 2 mod target 3

pub const fn control_in_2_mod_target_4(&self) -> ControlInModTarget

Gets the control in 2 mod target 4

pub const fn control_in_1_mod_amt_1(&self) -> isize

Gets the control in 1 mod amt 1

Range: -128..=127

pub const fn control_in_1_mod_amt_2(&self) -> isize

Gets the control in 1 mod amt 2

Range: -128..=127

pub const fn control_in_1_mod_amt_3(&self) -> isize

Gets the control in 1 mod amt 3

Range: -128..=127

pub const fn control_in_1_mod_amt_4(&self) -> isize

Gets the control in 1 mod amt 4

Range: -128..=127

pub const fn control_in_2_mod_amt_1(&self) -> isize

Gets the control in 2 mod amt 1

Range: -128..=127

pub const fn control_in_2_mod_amt_2(&self) -> isize

Gets the control in 2 mod amt 2

Range: -128..=127

pub const fn control_in_2_mod_amt_3(&self) -> isize

Gets the control in 2 mod amt 3

Range: -128..=127

pub const fn control_in_2_mod_amt_4(&self) -> isize

Gets the control in 2 mod amt 4

Range: -128..=127

Calls the kit sounds’ link_parameter_lock_pool method.

Please check link_parameter_lock_pool for more information.

Errors

Returns an error if the sound is a pool sound which does not support parameter locks.