pub enum PatternMode {
Sequential,
DirectStart,
DirectJump,
TempJump,
}Expand description
Excerpt from the manual
When changing patterns, different modes affecting the way the active pattern will be changed exist.
Press [FUNC] + [BANK A–D] to select PATTERN mode. The
There are four PATTERN modes.
- SEQUENTIAL changes patterns after the currently playing pattern reaches its end. This mode is the default mode.
- DIRECT START immediately changes patterns. The new pattern will start playing from the beginning.
- DIRECT JUMP immediately changes patterns. The new pattern will start playing from the position where the previous pattern left off.
- TEMP JUMP works a little bit differently from the other PATTERN modes. It works like this:
- Press
[FUNC]+[BANK D]to arm TEMP JUMP PATTERN mode. The Temp Jump LED starts to flash (if the sequencer is running) to indicate that Temp Jump mode is armed. - Select a new pattern. The Temp Jump LED is now firmly lit to indicate that Temp Jump mode is active The pattern changes immediately and the new pattern starts playing from the position where the previous pattern left off. It plays the new pattern once to the end and then return to the pattern that was playing before the change. Once the sequencer has returned to the earlier pattern, then TEMP JUMP mode is no longer active.
You can also use TEMP JUMP mode when you are in CHAIN mode, but then the pattern you change to instead replaces the current pattern in the chain. For example, say that you have a chain set up like this: A01 > A03 > A04 > A02. When the chain is playing, and you are in TEMP JUMP mode, change pattern to A16 while pattern A03 is playing. The pattern will immediately change to A16 and once A16 has ended then the chain will continue to play from pattern A04.
Variants