ObjectQuery

Trait ObjectQuery 

pub trait ObjectQuery:
    SysexCompatible
    + Send
    + Sync {
    // Required methods
    fn sysex_type(&self) -> AnySysexType;
    fn device_id(&self) -> u8;
    fn obj_nr(&self) -> u16;

    // Provided methods
    fn as_sysex_meta(&self) -> SysexMeta { ... }
    fn is_targeting_work_buffer(&self) -> bool { ... }
}
A trait which is implemented by all structures which can be converted to rytm sysex query messages.

Required Methods

fn sysex_type(&self) -> AnySysexType

Returns the sysex type of the object.

fn device_id(&self) -> u8

Returns the device id of the object.

fn obj_nr(&self) -> u16

Returns the object number (index) of the object.

Provided Methods

fn as_sysex_meta(&self) -> SysexMeta

Returns the sysex meta data for the object creating it.

fn is_targeting_work_buffer(&self) -> bool

Returns the information if this query is targeting the work buffer.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors